
% declare endogenous variables (assume K=16)

%% set the number of sectors
@#define secnum = 16


% var ey pi y R;            % variables (aggregate)
var ppi y R ye;            % variables (aggregate)

% variables (sectoral)
@#for i in 1:secnum   
     var pi@{i}
          pr@{i}
          pre@{i}
          a@{i}
          mu@{i};
@#endfor

% variables with data (aggregate)
var Dy;		  

% variables with data (sectoral)
@#for i in 1:secnum   
     var Dpi@{i}
          Da@{i};
@#endfor


% declare exogenous variables (innovations to the shocks)

varexo vy;

@#for i in 1:secnum
   varexo va@{i}
             vmu@{i};
@#endfor


% declare parameters

parameters sigma bet varphi theta eta;
@#for i in 1:secnum
   parameters n@{i}
	     alph@{i} 
	     rhoa@{i}
 	     rhomu@{i}; 
@#endfor


%% parameter values
sigma = 2;
bet   = 0.99; 
varphi = 1;
eta     = 3;
theta   = 6;

% load .mat files with parameter values
load calvo.mat
load size.mat

% Sectoral parameter values (alpha and n)
@# for i in 1:secnum
   set_param_value('alph@{i}', calvo(@{i}));
@# endfor

@# for i in 1:secnum
   set_param_value('n@{i}', size(@{i}));
@# endfor


 @#for i in 1:secnum
    rhoa@{i} = 0.9;
 @#endfor

 @#for i in 1:secnum
    rhomu@{i} = 0.9;
 @#endfor

%% model (LOG-LINEAR SYSTEM)

model(linear);


% compound parameters
@# for i in 1:secnum
   #kapp@{i} = (1-alph@{i})*(1-alph@{i}*bet)/alph@{i}* 1/(1+theta*varphi);
@#endfor


% equilibrium equations

   y = y(+1) - 1/sigma*(R - ppi(+1));

   0 = 
         @#for i in 1:secnum
       	 +n@{i}*pr@{i}
         @#endfor
	;



   @#for i in 1:secnum
	pi@{i} = bet * pi@{i}(+1) + kapp@{i}*(sigma+varphi)*y - kapp@{i}*(1 + varphi*eta)*pr@{i} - kapp@{i}*(1+varphi)*a@{i}  - kapp@{i}*(1/(theta-1))*mu@{i} ;                                                % sectoral Phillips curve
	pi@{i} - ppi = pr@{i} - pr@{i}(-1);   % identity equation for relative price pr
   @#endfor

ye = 
       @#for i in 1:secnum
	+n@{i}*a@{i}
       @#endfor
         ;

   @#for i in 1:secnum
 	pre@{i} = 
		@#for j in 1:secnum
		    +n@{j}*a@{j}
		@#endfor
		-a@{i};
   @#endfor

   ppi + y - y(-1) = vy; %%%	   % monetary policy


% shock processes (productivity and cost-push shocks)

   @#for i in 1:secnum
	a@{i} = rhoa@{i}*a@{i}(-1) + va@{i};
	mu@{i} = rhomu@{i}*mu@{i}(-1) + vmu@{i};
   @#endfor

 %  ey    = vy;    %%%

% measurement equations
   Dy    = y;

   @#for i in 1:secnum
	Dpi@{i} = pi@{i};
	Da@{i} = a@{i};
   @#endfor

end;


% set prior distributions for the parameters

estimated_params;

@#for i in 1:secnum
rhomu@{i},	0.9,	1e-8,	100,		beta_pdf, 		0.7,	0.15;
@#endfor

@#for i in 1:secnum
rhoa@{i}, 		0.9,	1e-8,	100,		beta_pdf, 		0.7,	0.15;
@#endfor

@#for i in 1:secnum 
stderr vmu@{i},	 	2/100,   inv_gamma_pdf,  2/100,  0.5;		
@#endfor

@#for i in 1:secnum 
stderr va@{i}, 		2/100,    inv_gamma_pdf,  2/100,  0.5;		
@#endfor

stderr vy, 	 	2/100,  inv_gamma_pdf,  2/100,  0.5;	

end;

steady;
check;
%stoch_simul;

% declare observable variables

varobs  Dy
@#for i in 1:secnum
      Dpi@{i} Da@{i}
@#endfor
    ;

identification(parameter_set=prior_mean,advanced=1);

options_.debug=1;

estimation(datafile='data_empreq_short.mat', mode_compute=5, mode_check, fast_kalman_filter, prior_trunc=0, order=1, mh_replic=5000, mh_nblocks=2, mh_jscale=0.25, mh_drop=0.33);


